@@ -52,7 +52,7 @@ import logging
 from pathlib import Path
 from PyQt6 import QtWidgets
 
-from not1mm.lib.plugin_common import gen_adif, get_points, online_score_xml
+from not1mm.lib.plugin_common import gen_adif, imp_adif, get_points, online_score_xml
 from not1mm.lib.version import __version__
 
 logger = logging.getLogger(__name__)
@@ -154,8 +154,9 @@ def predupe(self):
 
 def prefill(self):
     """Fill sentnr"""
-    result = self.database.get_serial()
-    serial_nr = str(result.get("serial_nr", "1")).zfill(3)
+    # result = self.database.get_serial()
+    # serial_nr = str(result.get("serial_nr", "1")).zfill(3)
+    serial_nr = str(self.current_sn).zfill(3)
     if serial_nr == "None":
         serial_nr = "001"
 
@@ -166,6 +167,10 @@ def prefill(self):
 
 def points(self):
     """Calc point"""
+
+    if self.contact_is_dupe > 0:
+        return 0
+
     _mode = self.contact.get("Mode", "")
     if _mode in "SSB, USB, LSB, FM, AM":
         return 2
@@ -267,7 +272,7 @@ def cabrillo(self, file_encoding):
     logger.debug("%s", filename)
     log = self.database.fetch_all_contacts_asc()
     try:
-        with open(filename, "w", encoding=file_encoding) as file_descriptor:
+        with open(filename, "w", encoding=file_encoding, newline="") as file_descriptor:
             output_cabrillo_line(
                 "START-OF-LOG: 3.0",
                 "\r\n",
